@@ -1,24 +1,30 @@
 package Task::CPANAuthors::STRO;
 
-# $Id: STRO.pm 11 2009-11-20 13:39:02Z stro $
+# $Id: STRO.pm 19 2009-12-23 17:40:47Z stro $
 
 use strict;
 use warnings;
 
-our $VERSION = '2009.1120';
+our $VERSION = '2009.1223';
 
 1;
 
 =head1 NAME
 
-Task::CPANAuthors::STRO
+Task::CPANAuthors::STRO - "Task" for installing modules maintained by STRO
 
 =head1 SYNOPSIS
 
+ perl -MCPAN -e 'install CPAN::Reporter'
+ perl -MCPAN -e 'o conf init test_report'
  perl -MCPAN -e 'install Task::CPANAuthors::STRO'
 
 =head1 CONTENTS
 
+CGI-Application-Plugin-DevPopup-Params
+
+CGI-Application-Plugin-DevPopup-Query
+
 Data::Define
 
 FindBin::Real
@@ -51,4 +57,9 @@ Task:: of modules I maintain.
 
 Serguei Trouchelle E<lt>F<stro@cpan.org>E<gt>
 
+=head1 LICENSE AND COPYRIGHT
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
 =cut 
